@@ -3,10 +3,11 @@
 import argparse
 import base64
 import hashlib
+from typing import Union
 from urllib.parse import urlparse, parse_qs
 import pymongo
-import requests
 import yaml
+from perun.connector import AdaptersManager
 from pymongo.errors import OperationFailure
 from Cryptodome.Cipher import AES
 from Cryptodome.Util.Padding import unpad
@@ -23,7 +24,11 @@ def get_config():
     parser = argparse.ArgumentParser()
     parser.add_argument("config_filepath", type=str, help="path_to_config_file")
     arguments = parser.parse_args()
-    with open(arguments.config_filepath, "r") as ymlfile:
+    return load_yaml_from_file(arguments.config_filepath)
+
+
+def load_yaml_from_file(filepath):
+    with open(filepath, "r") as ymlfile:
         cfg = yaml.safe_load(ymlfile)
         return cfg
 
@@ -40,37 +45,19 @@ def get_attr_perun_names(cfg):
 
 
 def get_data(cfg):
-    rpc_url = cfg["rpc"]["perun_url"]
-    rpc_facilities = "{}json/searcher/getFacilities".format(rpc_url)
-    rpc_username = cfg["rpc"]["perun_user"]
-    rpc_password = cfg["rpc"]["perun_password"]
-    resp = requests.post(
-        rpc_facilities,
-        json={
-            "attributesWithSearchingValues": {
-                cfg["attributes"]["rp_type"]: cfg["rp_type_attr_value"],
-                cfg["attributes"]["proxy_identifier"]: cfg["proxy_identifier_value"],
-            }
-        },
-        auth=(rpc_username, rpc_password),
+    attributes_map = load_yaml_from_file(cfg["attrs_cfg_path"])
+    adapters_manager = AdaptersManager(cfg["adapters_manager"], attributes_map)
+
+    facilities_list = adapters_manager.get_facilities_by_attribute_with_attributes(
+        cfg["attributes"]["proxy_identifier"],
+        cfg["proxy_identifier_value"],
+        get_attr_perun_names(cfg),
     )
-    if resp.status_code != 200:
-        print("facility invalid response")
-        return "INVALID RESPONSE"
-    facilities_list = resp.json()
+
     present_client_ids = []
     collection = get_collection(cfg)
     for facility in facilities_list:
-        resp = requests.post(
-            "{}json/attributesManager/getAttributes".format(cfg["rpc"]["perun_url"]),
-            json={"facility": facility["id"], "attrNames": get_attr_perun_names(cfg)},
-            auth=(rpc_username, rpc_password),
-        )
-        if resp.status_code != 200:
-            print("attributes invalid response")
-            return "INVALID RESPONSE"
-        facility_attrs = resp.json()
-        attrs_dict = get_attr_dict(cfg, facility_attrs)
+        attrs_dict = get_attr_dict(cfg, facility.attributes)
         print("Processing client_id: {}.".format(attrs_dict["client_id"]))
         try:
             result = collection.replace_one(
@@ -107,24 +94,25 @@ def get_issue_refresh_tokens_value(cfg, facility_attrs):
             return attr["value"] is True
 
 
-def get_attr_dict(cfg, facility_attrs):
+def get_attr_dict(
+    cfg, facility_attrs: dict[str, Union[str, int, bool, list[str], dict[str, str]]]
+):
     result = {}
     for key, value in cfg["static_attributes"].items():
         result[key] = value
 
-    for attr in facility_attrs:
-        attr_perun_name = attr["namespace"] + ":" + attr["baseFriendlyName"]
+    for perun_attr_name, perun_attr_value in facility_attrs.items():
         for key, value in cfg["attributes"].items():
-            if isinstance(value, list) and attr_perun_name in value:
+            if isinstance(value, list) and perun_attr_name in value:
                 if key in result:
-                    result[key].append(attr["value"])
+                    result[key].append(perun_attr_value)
                 else:
-                    result[key] = [attr["value"]]
-            elif value == attr_perun_name:
+                    result[key] = [perun_attr_value]
+            elif value == perun_attr_name:
                 if key == "redirect_uris":
-                    if attr["value"]:
+                    if perun_attr_value:
                         uris = {}
-                        for uri in attr["value"]:
+                        for uri in perun_attr_value:
                             parsed_url = urlparse(uri)
                             uri = (
                                 parsed_url._replace(query="")
@@ -143,15 +131,15 @@ def get_attr_dict(cfg, facility_attrs):
                 elif key == "client_secret":
                     result[key] = (
                         None
-                        if attr["value"] is None or attr["value"] == "null"
-                        else decrypt_secret(attr["value"], cfg["encryption_key"])
+                        if perun_attr_value is None or perun_attr_value == "null"
+                        else decrypt_secret(perun_attr_value, cfg["encryption_key"])
                     )
                 elif key == "flow_types":
                     issue_refresh_tokens = get_issue_refresh_tokens_value(
                         cfg, facility_attrs
                     )
                     grant_types, response_types = set_grant_and_response_types(
-                        attr["value"], issue_refresh_tokens
+                        perun_attr_value, issue_refresh_tokens
                     )
                     result["grant_types_supported"] = grant_types
                     result["response_types"] = response_types
@@ -162,24 +150,23 @@ def get_attr_dict(cfg, facility_attrs):
                     "logo_uri",
                     "client_uri",
                 ]:
-                    if not attr["value"] or isinstance(attr["value"], str):
-                        result[key] = attr["value"]
+                    if not perun_attr_value or isinstance(perun_attr_value, str):
+                        result[key] = perun_attr_value
                     else:
-                        for lan, trans in attr["value"].items():
+                        for lan, trans in perun_attr_value.items():
                             if key not in result:
                                 result[key] = trans
                             result[key + "#" + lan] = trans
                 elif key == "code_challenge_type":
-                    if attr["value"] and attr["value"] != "none":
+                    if perun_attr_value and perun_attr_value != "none":
                         result["pkce_essential"] = True
                 elif key == "post_logout_redirect_uri":
-                    result[key] = [attr["value"], None]
+                    result[key] = [perun_attr_value, None]
                 elif key not in [
                     "master_proxy_identifier",
                     "proxy_identifier",
-                    "rp_type",
                 ]:
-                    result[key] = attr["value"]
+                    result[key] = perun_attr_value
     return result
 
 
